Learn R Programming

plausibounds (version 1.0.1)

estimates_bighump: Sinusoidal Estimates with Moderate Correlation

Description

A dataset containing estimates with a curved sinusoidal pattern in the first 6 periods that then converges to zero for the remaining 30 periods. The effect is a smooth curved trajectory with a large dip before the treatment effect quickly returns to 0. Generated with moderate correlation (rho = 0.5).

Usage

estimates_bighump

Arguments

Format

A numeric vector with 36 elements

Examples

Run this code
data(estimates_bighump)
data(var_bighump)
result <- plausible_bounds(estimates_bighump[1:4], var_bighump[1:4, 1:4])
create_plot(result)

Run the code above in your browser using DataLab