Enhances dynamic effect plots as suggested in Freyaldenhoven and Hansen (2026). Data-driven smoothing delivers a smooth estimated path with potentially improved point estimation properties and confidence regions covering a surrogate that can be substantially tighter than conventional pointwise or uniform bands.
plausible_bounds: Calculate plausible bounds
create_plot: Create plots of the bounds
The package includes example datasets to demonstrate the functionality:
estimates_constant and var_constant:
A simple case with constant estimates and no correlation
estimates_bighump and var_bighump:
A case with sinusoidal estimates and moderate correlation
estimates_smooth and var_smooth:
A smooth case with effects that slowly level off and no correlation, from Figure 1 of Freyaldenhoven and Hansen (2026)